@@ -3,390 +3,378 @@
 ###################################################
 ### code chunk number 1: probhat.Rnw:35-39
 ###################################################
-options(continue=" ")
+options(continue=" ", width=80)
 options(SweaveHooks=list(fig=function()
 par(mar=c(4.1, 4.1, 2.6, 1.6), cex=0.7, cex.main=1)))
 set.seed (1)
 
 
 ###################################################
-### code chunk number 2: probhat.Rnw:198-201
+### code chunk number 2: probhat.Rnw:153-157
 ###################################################
-library (probhat)
-library (fclust)
-library (scatterplot3d)
+library (probhat)       #required
+library (vectools)      #optional, used in appendix
+library (fclust)        #optional, used in appendix
+library (scatterplot3d) #optional
 
 
 ###################################################
-### code chunk number 3: probhat.Rnw:208-209
+### code chunk number 3: probhat.Rnw:164-165
 ###################################################
-use.ph.theme ("green")
+set.ph.options (rendering.style="e", theme="green")
 
 
 ###################################################
-### code chunk number 4: probhat.Rnw:214-215
+### code chunk number 4: probhat.Rnw:170-171
 ###################################################
-data.prep ()
+ph.data.prep ()
 
 
 ###################################################
-### code chunk number 5: probhat.Rnw:227-228
+### code chunk number 5: probhat.Rnw:185-188
 ###################################################
-fh = pmfuv.dks (traffic.x, traffic.h, bw=23, lower=0)
+dfh <- pmfuv.dks (traffic.bins, traffic.freq, lower=0)
+dFh <- cdfuv.dks (traffic.bins, traffic.freq, lower=0)
+dFht <- qfuv.dks (traffic.bins, traffic.freq, lower=0)
 
 
 ###################################################
-### code chunk number 6: probhat.Rnw:232-233
+### code chunk number 6: probhat.Rnw:192-193
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (fh, TRUE)
+plot (dfh, TRUE, main="Probability Mass Function")
 
 
 ###################################################
-### code chunk number 7: probhat.Rnw:243-244
-###################################################
-fh (10)
-
-
-###################################################
-### code chunk number 8: probhat.Rnw:249-251
-###################################################
-Fh = cdfuv.dks (traffic.x, traffic.h, bw=23, lower=0)
-Fh.inv = qfuv.dks (traffic.x, traffic.h, bw=23, lower=0)
-
-
-###################################################
-### code chunk number 9: probhat.Rnw:255-256
+### code chunk number 7: probhat.Rnw:195-196
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh, TRUE)
+plot (dfh, TRUE, freq=TRUE, main="same as above\nbut with frequencies")
 
 
 ###################################################
-### code chunk number 10: probhat.Rnw:259-260
+### code chunk number 8: probhat.Rnw:198-199
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh.inv)
+plot (dFh, TRUE, main="Cumulative Distribution Function")
 
 
 ###################################################
-### code chunk number 11: probhat.Rnw:279-280
-###################################################
-fh = pdfuv.cks (Height)
-
-
-###################################################
-### code chunk number 12: probhat.Rnw:284-285
+### code chunk number 9: probhat.Rnw:201-202
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (fh, TRUE)
+plot (dFht, main="Quantile Function")
 
 
 ###################################################
-### code chunk number 13: probhat.Rnw:293-294
+### code chunk number 10: probhat.Rnw:211-214
 ###################################################
-fh (22)
+dfh (10)
+dfh (10, freq=TRUE)
+dFht (c (0.25, 0.5, 0.75) )
 
 
 ###################################################
-### code chunk number 14: probhat.Rnw:299-301
+### code chunk number 11: probhat.Rnw:231-234
 ###################################################
-Fh = cdfuv.cks (Height)
-Fh.inv = qfuv.cks (Height)
+cfh <- pdfuv.cks (height)
+cFh <- cdfuv.cks (height)
+cFht <- qfuv.cks (height)
 
 
 ###################################################
-### code chunk number 15: probhat.Rnw:305-306
+### code chunk number 12: probhat.Rnw:238-239
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh, TRUE)
+plot (cfh, TRUE, main="Probability Density Function")
 
 
 ###################################################
-### code chunk number 16: probhat.Rnw:309-310
+### code chunk number 13: probhat.Rnw:241-242
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh.inv)
+plot (cFh, TRUE, main="Cumulative Distribution Function")
 
 
 ###################################################
-### code chunk number 17: probhat.Rnw:318-320
-###################################################
-p1 = 0.5
-p2 = Fh (Fh.inv (p1) )
-
-
-###################################################
-### code chunk number 18: probhat.Rnw:323-325
-###################################################
-p1 == p2
-abs (p1 - p2)
-
-
-###################################################
-### code chunk number 19: probhat.Rnw:335-336
-###################################################
-fh = pdfmv.cks (trees [,2:3])
-
-
-###################################################
-### code chunk number 20: probhat.Rnw:339-340
+### code chunk number 14: probhat.Rnw:244-245
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (fh, all=TRUE)
+plot (cFht, main="Quantile Function")
 
 
 ###################################################
-### code chunk number 21: probhat.Rnw:346-347
+### code chunk number 15: probhat.Rnw:252-254
 ###################################################
-fh (c (22, 0.8) )
+cfh (22)
+cFht (c (0.25, 0.5, 0.75) )
 
 
 ###################################################
-### code chunk number 22: probhat.Rnw:351-352
+### code chunk number 16: probhat.Rnw:265-267
 ###################################################
-Fh = cdfmv.cks (trees [,2:3])
+cfh2 <- pdfmv.cks (quakes [,1:2], smoothness = c (0.35, 1) )
+cfh3 <- pdfmv.cks (quakes [,1:3], smoothness = c (0.35, 1, 1) )
 
 
 ###################################################
-### code chunk number 23: probhat.Rnw:356-357
+### code chunk number 17: probhat.Rnw:271-273
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh, all=TRUE)
+plot (cfh2,, TRUE,
+    main="Bivariate PDF, 2D")
 
 
 ###################################################
-### code chunk number 24: probhat.Rnw:368-370
-###################################################
-conditions = c (Girth=30, Height=22)
-cfh = pdfc.cks (trees, conditions=conditions)
-
-
-###################################################
-### code chunk number 25: probhat.Rnw:374-375
+### code chunk number 18: probhat.Rnw:275-276
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (cfh)
+plot (cfh2, TRUE, main="Bivariate PDF, 3D")
 
 
 ###################################################
-### code chunk number 26: probhat.Rnw:380-382
-###################################################
-#density of volume (volume=0.85), given girth=30 and height=22
-cfh (0.85)
-
-
-###################################################
-### code chunk number 27: probhat.Rnw:396-398
-###################################################
-conditions = c (lat=-20, long=180)
-cfh = pdfmvc.cks (quakes, conditions=conditions)
-
-
-###################################################
-### code chunk number 28: probhat.Rnw:402-403
+### code chunk number 19: probhat.Rnw:278-280
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (cfh, xlim = c (0, 800) )
+plot (cfh3, main="Trivariate PDF",
+    nslides=8, zlim = c (680, 40) )
 
 
 ###################################################
-### code chunk number 29: probhat.Rnw:405-406
+### code chunk number 20: probhat.Rnw:288-290
+###################################################
+cfh2 (c (180, -20) )
+cfh3 (c (180, -20, 300) )
+
+
+###################################################
+### code chunk number 21: probhat.Rnw:306-307
+###################################################
+conditions <- c (long=180, lat=-20)
+
+
+###################################################
+### code chunk number 22: probhat.Rnw:310-314
+###################################################
+depth.fhc <- pdfc.cks (quakes [,-4], smoothness = c (0.35, 1, 1),
+    conditions=conditions, preserve.range=TRUE)
+mag.fhc <- pdfc.cks (quakes [,-3], smoothness = c (0.35, 1, 1),
+    conditions=conditions, preserve.range=TRUE)
+
+
+###################################################
+### code chunk number 23: probhat.Rnw:318-319
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (cfh, TRUE, xlim = c (0, 800) )
+plot (depth.fhc, main="conditional distribution of depth\n(long=180, lat=-20)")
 
 
 ###################################################
-### code chunk number 30: probhat.Rnw:416-420
-###################################################
-cfh.AA = pdfmvc.cks (quakes, conditions = c (lat=-30, long=170) )
-cfh.AB = pdfmvc.cks (quakes, conditions = c (lat=-30, long=180) )
-cfh.BA = pdfmvc.cks (quakes, conditions = c (lat=-20, long=170) )
-cfh.BB = cfh
-
-
-###################################################
-### code chunk number 31: probhat.Rnw:424-428
+### code chunk number 24: probhat.Rnw:321-322
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot_2x2 (cfh.AA, cfh.AB, cfh.BA, cfh.BB,
-    "lat=-30, long=170", "lat=-30, long=180",
-    "lat=-20, long=170", "lat=-20, long=180",
-    xlim = c (0, 800) )
+plot (mag.fhc, main="conditional distribution of mag\n(long=180, lat=-20)")
 
 
 ###################################################
-### code chunk number 32: probhat.Rnw:434-436
+### code chunk number 25: probhat.Rnw:335-339
 ###################################################
-cfh.A = pdfmvc.cks (quakes [,-4], conditions = c (depth=100) )
-cfh.B = pdfmvc.cks (quakes [,-4], conditions = c (depth=500) )
+depth.mag.fhc <- pdfmvc.cks (quakes, smoothness = c (0.35, 1, 1, 1),
+    conditions = c (long=180, lat=-20), preserve.range=TRUE)
+lat.long.fhc <- pdfmvc.cks (quakes [,-4], smoothness = c (0.35, 1, 1),
+    conditions = c (depth=168), preserve.range=TRUE)
 
 
 ###################################################
-### code chunk number 33: probhat.Rnw:440-441
+### code chunk number 26: probhat.Rnw:343-345
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (cfh.A, main="depth=100")
+plot (depth.mag.fhc,
+    main="conditional distribution of depth and mag\n(long=180, lat=-20)")
 
 
 ###################################################
-### code chunk number 34: probhat.Rnw:443-444
+### code chunk number 27: probhat.Rnw:347-349
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (cfh.B, main="depth=500")
+plot (lat.long.fhc,
+    main="conditional distribution of lat and long\n(depth=168)")
 
 
 ###################################################
-### code chunk number 35: probhat.Rnw:457-458
+### code chunk number 28: probhat.Rnw:363-364
 ###################################################
-fh = pmfuv.cat (region)
+gfh <- pmfuv.cat (crime.type, n.arrests)
 
 
 ###################################################
-### code chunk number 36: probhat.Rnw:462-463
+### code chunk number 29: probhat.Rnw:368-369
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (fh)
+plot (gfh, main="Probability Mass Function")
 
 
 ###################################################
-### code chunk number 37: probhat.Rnw:468-470
-###################################################
-fh (1)
-fh ("North Central")
-
-
-###################################################
-### code chunk number 38: probhat.Rnw:484-486
-###################################################
-mean.Sepal.Length = mean (iris.Sepal.Length)
-fh = pmfc.cat.cks (iris.Species, iris.Sepal.Length, at=mean.Sepal.Length)
-
-
-###################################################
-### code chunk number 39: probhat.Rnw:490-491
+### code chunk number 30: probhat.Rnw:371-372
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (fh)
+plot (gfh, freq=TRUE, main="same as above\nbut with frequencies")
 
 
 ###################################################
-### code chunk number 40: probhat.Rnw:504-505
+### code chunk number 31: probhat.Rnw:379-380
 ###################################################
-Fh = cdf.el (Height)
+levels (crime.type$crime.type)
 
 
 ###################################################
-### code chunk number 41: probhat.Rnw:509-510
+### code chunk number 32: probhat.Rnw:383-385
+###################################################
+gfh (1)
+gfh ("Assault")
+
+
+###################################################
+### code chunk number 33: probhat.Rnw:388-389
+###################################################
+gfh ("Assault", freq=TRUE)
+
+
+###################################################
+### code chunk number 34: probhat.Rnw:405-407
+###################################################
+eFh <- cdf.el (height)
+eFht <- qf.el (height)
+
+
+###################################################
+### code chunk number 35: probhat.Rnw:411-412
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh)
+plot (eFh, main="Cumulative Distribution Function")
 
 
 ###################################################
-### code chunk number 42: probhat.Rnw:516-517
-###################################################
-Fh.inv = qf.el (Height)
-
-
-###################################################
-### code chunk number 43: probhat.Rnw:521-522
+### code chunk number 36: probhat.Rnw:414-415
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh.inv)
+plot (eFht, main="Quantile Function")
 
 
 ###################################################
-### code chunk number 44: probhat.Rnw:550-551
-###################################################
-cs = categorical.set (pdfuv.cks, iris.Sepal.Length, group.by=iris.Species)
-
-
-###################################################
-### code chunk number 45: probhat.Rnw:555-556
+### code chunk number 37: probhat.Rnw:442-446
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (cs)
+fh1a.gmix <- pmfc.gmixp (species, sepal.length,
+    conditions = c (sepal.length=5.5) )
+plot (fh1a.gmix,
+    main="Conditional Distribution of Iris Species\n(sepal.length=5.5)")
 
 
 ###################################################
-### code chunk number 46: probhat.Rnw:561-563
-###################################################
-conditions = cbind (Height = c (20, 24, 28) )
-cond.set = conditional.set (pdfc.cks, trees [,2:3], group.by=conditions)
-
-
-###################################################
-### code chunk number 47: probhat.Rnw:567-568
+### code chunk number 38: probhat.Rnw:448-452
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (cond.set)
+fh1b.gmix <- pmfc.gmixp (species, sepal.length,
+    conditions = c (sepal.length=6.5) )
+plot (fh1b.gmix,
+    main="Conditional Distribution of Iris Species\n(sepal.length=6.5)")
 
 
 ###################################################
-### code chunk number 48: probhat.Rnw:578-579
-###################################################
-ms = marginal.set (qf.el, trees)
-
-
-###################################################
-### code chunk number 49: probhat.Rnw:583-584
+### code chunk number 39: probhat.Rnw:460-468
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (ms)
+fh2.gmix <- pmfc.gmixp (species, cbind (sepal.length, sepal.width),
+    conditions = c (sepal.length=6, sepal.width=3) )
+plot (fh2.gmix,
+    main = paste (
+        "Conditional Distribution of Iris Species",
+        "(sepal.length=6, sepal.width=3)",
+        sep="\n")
+    )
 
 
 ###################################################
-### code chunk number 50: probhat.Rnw:596-598
+### code chunk number 40: probhat.Rnw:477-479
+###################################################
+ph.mode (fh2.gmix)
+gmode (fh2.gmix)
+
+
+###################################################
+### code chunk number 41: probhat.Rnw:495-496
+###################################################
+fh.gset <- pdfuv.gset.cks (sepal.length, group.by=species)
+
+
+###################################################
+### code chunk number 42: probhat.Rnw:500-501
+###################################################
+getOption("SweaveHooks")[["fig"]]()
+plot (fh.gset, main="Density Estimates of Sepal Length\n(grouped by species)")
+
+
+###################################################
+### code chunk number 43: probhat.Rnw:507-508
+###################################################
+Fht.mset = qfuv.mset.el (trees)
+
+
+###################################################
+### code chunk number 44: probhat.Rnw:512-513
+###################################################
+getOption("SweaveHooks")[["fig"]]()
+plot (Fht.mset, nr=2, nc=2)
+
+
+###################################################
+### code chunk number 45: probhat.Rnw:525-527
 ###################################################
 #multivariate cdf
-Fh = cdfmv.cks (trees)
+cFh3 <- cdfmv.cks (trees)
 
 
 ###################################################
-### code chunk number 51: probhat.Rnw:601-604
+### code chunk number 46: probhat.Rnw:530-536
 ###################################################
-#approximate first and third quartiles
-a = c (28, 22, 0.55)
-b = c (38, 24, 1.05)
+q <- matrix (c (
+    22, 24,    #height in 22 to 24
+    28, 38,    #girth  in 28 to 38
+    0.55, 1.05 #volume in 0.55 to 1.05
+    ),, 2, byrow=TRUE, dimnames = list (colnames (trees), c ("a", "b") ) )
+q
 
 
 ###################################################
-### code chunk number 52: probhat.Rnw:607-608
-###################################################
-cbind (lower=a, upper=b)
-
-
-###################################################
-### code chunk number 53: probhat.Rnw:611-613
+### code chunk number 47: probhat.Rnw:539-541
 ###################################################
 #multivariate probability
-probmv (Fh, a, b)
+probmv (cFh3, q [,1], q [,2])
 
 
 ###################################################
-### code chunk number 54: probhat.Rnw:642-644
+### code chunk number 48: probhat.Rnw:560-562
 ###################################################
-chF.inv = chqf.cks (trees)
-synthetic.data = ph.rng (chF.inv, 31)
+chFht <- chqf.cks (trees)
+synthetic.data <- rng (chFht, 31)
 
 
 ###################################################
-### code chunk number 55: probhat.Rnw:647-655
+### code chunk number 49: probhat.Rnw:565-573
 ###################################################
 #convenience function
-plot.trees.data = function (x, main)
-{   Height = x [,"Height"]
-    Girth = x [,"Girth"]
-    Volume = x [,"Volume"]
-    scatterplot3d (Height, Girth, Volume,
+plot.trees.data <- function (x, main)
+{   height <- x [,"height"]
+    girth <- x [,"girth"]
+    volume <- x [,"volume"]
+    scatterplot3d (height, girth, volume,
         main=main, type="h", angle=112.5, pch=16)
 }
 
 
 ###################################################
-### code chunk number 56: probhat.Rnw:659-661
+### code chunk number 50: probhat.Rnw:577-579
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 #original data
@@ -394,7 +382,7 @@ plot.trees.data (trees, "original data")
 
 
 ###################################################
-### code chunk number 57: probhat.Rnw:664-666
+### code chunk number 51: probhat.Rnw:582-584
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 #synthetic data
@@ -402,83 +390,145 @@ plot.trees.data (synthetic.data, "synthetic data")
 
 
 ###################################################
-### code chunk number 58: probhat.Rnw:681-686
+### code chunk number 52: probhat.Rnw:621-625
 ###################################################
-#conditional distributions
-conditions = c (Height=24)
-cfh = pdfc.cks (trees [,2:3], conditions=conditions)
-cFh = cdfc.cks (trees [,2:3], conditions=conditions)
-cFh.inv = qfc.cks (trees [,2:3], conditions=conditions)
-
-
-###################################################
-### code chunk number 59: probhat.Rnw:689-693
-###################################################
-#mean, median and mode
-mean.Volume = ph.mean (cFh)
-median.Volume = cFh.inv (0.5)
-mode.Volume = ph.mode (cfh)
-
-
-###################################################
-### code chunk number 60: probhat.Rnw:696-698
-###################################################
-cbind (statistic = c ("mean", "median", "mode"),
-    value = c (mean.Volume, median.Volume, mode.Volume) )
-
-
-###################################################
-### code chunk number 61: probhat.Rnw:702-705
-###################################################
-getOption("SweaveHooks")[["fig"]]()
-plot (cfh)
-abline (v = c (mean.Volume, mode.Volume) )
-abline (v=median.Volume, lty=2)
-
-
-###################################################
-### code chunk number 62: probhat.Rnw:709-713
-###################################################
-#and just as an example, the variance, skewness and kurtosis...
+ph.mean (cFh)
 ph.var (cFh)
 ph.skewness (cFh)
 ph.kurtosis (cFh)
 
 
 ###################################################
-### code chunk number 63: probhat.Rnw:1028-1029
+### code chunk number 53: probhat.Rnw:637-639
 ###################################################
-data.prep (eval=FALSE, echo=TRUE)
+quartiles (cFht)
+deciles (cFht)
 
 
 ###################################################
-### code chunk number 64: probhat.Rnw:1046-1047
+### code chunk number 54: probhat.Rnw:642-644
 ###################################################
-membership = FKM.gk (unemployment, k=3, seed=2)$U
+ntiles (cFht, 8)
+ntiles (cFht, 8, rank=FALSE)
 
 
 ###################################################
-### code chunk number 65: probhat.Rnw:1052-1054
+### code chunk number 55: probhat.Rnw:647-650
 ###################################################
-w = membership [,1]
-w = w / sum (w)
+quartiles (cFht)
+quartiles (eFht)
+quartiles (height)
 
 
 ###################################################
-### code chunk number 66: probhat.Rnw:1059-1060
+### code chunk number 56: probhat.Rnw:662-664
 ###################################################
-wfh.1 = pdfmv.cks (unemployment, w=w)
+ph.median (cFht)
+ph.quantile (cFht, c (0.25, 0.5, 0.75) )
 
 
 ###################################################
-### code chunk number 67: probhat.Rnw:1064-1065
+### code chunk number 57: probhat.Rnw:667-669
+###################################################
+#inter-quartile range
+iqr (cFht)
+
+
+###################################################
+### code chunk number 58: probhat.Rnw:672-674
+###################################################
+#inter-quantile ranges
+iqr (cFht, 2/3)
+
+
+###################################################
+### code chunk number 59: probhat.Rnw:682-684
+###################################################
+cFht (0.5)
+ph.median (cFht)
+
+
+###################################################
+### code chunk number 60: probhat.Rnw:688-689
+###################################################
+ph.median (height)
+
+
+###################################################
+### code chunk number 61: probhat.Rnw:701-703
+###################################################
+ph.mode(cfh)
+ph.mode(cfh, TRUE)
+
+
+###################################################
+### code chunk number 62: probhat.Rnw:710-719
+###################################################
+height.summary <- c (
+    mean = ph.mean (cFh),         #CDF
+    sd = ph.sd (cFh),             #CDF
+    variance = ph.var (cFh),      #CDF
+    skewness = ph.skewness (cFh), #CDF
+    kurtosis = ph.kurtosis (cFh), #CDF
+                                  #
+    median = ph.median (cFht),    #QF
+    mode = ph.mode (cfh) )        #PDF
+
+
+###################################################
+### code chunk number 63: probhat.Rnw:722-727
+###################################################
+strs <- c (c ("mean", "median", "mode") )
+x <- height.summary [strs]
+y <- c (0.06, 0.1, 0.14)
+colors <- c ("black", "blue", "darkgreen")
+adjv <- c (1.25, 0.5, -0.25)
+
+
+###################################################
+### code chunk number 64: probhat.Rnw:731-735
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (wfh.1)
+plot (cfh)
+abline (v=x, col=colors)
+for (i in 1:3)
+    text (x [i], y [i], strs [i], adj = adjv [i], col = colors [i])
 
 
 ###################################################
-### code chunk number 68: probhat.Rnw:1068-1070
+### code chunk number 65: probhat.Rnw:739-740
+###################################################
+height.summary
+
+
+###################################################
+### code chunk number 66: probhat.Rnw:1146-1147
+###################################################
+membership <- FKM.gk (unemployment, k=3, seed=2)$U
+
+
+###################################################
+### code chunk number 67: probhat.Rnw:1152-1154
+###################################################
+w <- membership [,1]
+w <- w / sum (w)
+
+
+###################################################
+### code chunk number 68: probhat.Rnw:1159-1160
+###################################################
+wfh.1 <- pdfmv.cks (unemployment, w=w)
+
+
+###################################################
+### code chunk number 69: probhat.Rnw:1164-1165
+###################################################
+getOption("SweaveHooks")[["fig"]]()
+plot (wfh.1,, TRUE)
+
+
+###################################################
+### code chunk number 70: probhat.Rnw:1168-1170
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 k = 1 - w / max (w)
@@ -486,18 +536,54 @@ plot (unemployment, pch=16, col=rgb (k, k, k) )
 
 
 ###################################################
-### code chunk number 69: probhat.Rnw:1075-1079
+### code chunk number 71: probhat.Rnw:1175-1179
 ###################################################
-w = membership [,2]
+w <- membership [,2]
 wfh.2 = pdfmv.cks (unemployment, w = w / sum (w) )
-w = membership [,3]
+w <- membership [,3]
 wfh.3 = pdfmv.cks (unemployment, w = w / sum (w) )
 
 
 ###################################################
-### code chunk number 70: probhat.Rnw:1084-1085
+### code chunk number 72: probhat.Rnw:1183-1186 (eval = FALSE)
+###################################################
+## plot (wfh.1, main="cluster 1")
+## plot (wfh.2, main="cluster 2")
+## plot (wfh.3, main="cluster 3")
+
+
+###################################################
+### code chunk number 73: probhat.Rnw:1190-1196
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot_2x2 (wfh.1,, wfh.2, wfh.3, "cluster 1",, "cluster 2", "cluster 3")
+p0 <- par (mfrow = c (2, 2) )
+plot (wfh.1, main="cluster 1")
+plot.new ()
+plot (wfh.2, main="cluster 2")
+plot (wfh.3, main="cluster 3")
+par (p0)
+
+
+###################################################
+### code chunk number 74: probhat.Rnw:1204-1205
+###################################################
+ph.data.prep (eval=FALSE, echo=TRUE)
+
+
+###################################################
+### code chunk number 75: probhat.Rnw:1213-1214
+###################################################
+headt (cbind (traffic.bins, freq=traffic.freq) )
+
+
+###################################################
+### code chunk number 76: probhat.Rnw:1217-1223
+###################################################
+headt (trees)
+headt (quakes)
+headt (crimes)
+headt (data.frame (crime.type=crime.type$crime.type, n.arrests) )
+headt (data.frame (species, sepal.length, sepal.width) )
+headt (unemployment)
 
 
